bread.settings package
======================

.. automodule:: bread.settings
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.settings.required module
------------------------------

.. automodule:: bread.settings.required
   :members:
   :undoc-members:
   :show-inheritance:
